#!/usr/bin/python
"""Warden3 Filer Test Suite"""

import unittest2 as unittest
import warden_filer

idea_raw_1 = {
        'ID': '4dd7cf5e-4a95-49f6-8f04-947de998012c',
        'Format': 'IDEA0',
        'DetectTime': '2016-06-21T13:08:27Z',
        'WinStartTime': '2016-06-21T11:55:02Z',
        'WinEndTime': '2016-06-21T12:00:02Z',
        'Source': [
            {
                'IP4': ['188.14.166.39']
            }
        ],
        'Target': [
            {
                'IP4': ['195.113.165.128/25']
            }
        ],
        '_TO_DELETE': {
            'key1' : 'value',
            'key2' : 2
        },
        'Node': [
            {
                'Type': ['Relay'],
                'Name': 'cz.cesnet.mentat.warden_filer'
            }
        ],
        '_CESNET': {
            'StorageTime': '2016-06-21T14:00:07Z'
        }
    }
    
idea_filtered_1 = {
        'ID': '4dd7cf5e-4a95-49f6-8f04-947de998012c',
        'Format': 'IDEA0',
        'DetectTime': '2016-06-21T13:08:27Z',
        'WinStartTime': '2016-06-21T11:55:02Z',
        'WinEndTime': '2016-06-21T12:00:02Z',
        'Source': [
            {
                'IP4': ['188.14.166.39']
            }
        ],
        'Target': [
            {
                'IP4': ['195.113.165.128/25']
            }
        ],
        'Node': [
            {
                'Type': ['Relay'],
                'Name': 'cz.cesnet.mentat.warden_filer'
            }
        ]
    }

class Warden3FilerTest(unittest.TestCase):
    """Warden3 Filer unit tests"""
    
    def test_filter_by_regexp(self):
        regexp = '^_+'
        filtered = warden_filer.filter_by_regexp(idea_raw_1, regexp)
        self.assertEquals(filtered, idea_filtered_1)
        
        event = {
            'ID' : '1',
            'Node' : {
            	'_INTERNAL' : 'data'
            }
        }
        
        filtered = warden_filer.filter_by_regexp(event, regexp)
        
        # only first level keys are filtered
        self.assertEquals(filtered, event) 
        
if __name__ == "__main__":
    unittest.main()
